Make a new release by merging the release-plz PR.

If there are any breaking changes:

1. Edit (push a new commit to) the release-plz PR, in which you, for each breaking change, elaborate on the change and
   provide a clear migration option.
